#!/bin/bash

if [ "$IMAGE_TAG" == "" ]; then
  echo "Make sure IMAGE_TAG is set"
  exit 1
fi
if [ "$GPG_PASSPHRASE" == "" ]; then
  echo "Make sure GPG_PASSPHRASE is set"
  exit 1
fi

IMAGE_NAME=gitea.hottis.de/wn/pv-energy-calculator
NAMESPACE=homea
DEPLOYMENT_DIR=$PWD/deployment

pushd $DEPLOYMENT_DIR > /dev/null
SECRETS_FILE=`mktemp`
pwd
id
echo $HOME
gpg --decrypt --passphrase $GPG_PASSPHRASE --yes --batch --homedir /tmp/.gnupg --output $SECRETS_FILE secrets.asc
. $SECRETS_FILE
rm $SECRETS_FILE

kubectl create namespace $NAMESPACE \
  --dry-run=client \
  -o yaml | \
  kubectl -f - apply

kubectl create secret generic pv-energy-calculator \
  --dry-run=client \
  -o yaml \
  --save-config \
  --from-literal=PGPASSWORD="$PGPASSWORD" | \
  kubectl apply -f - -n $NAMESPACE

cat $DEPLOYMENT_DIR/deploy-yml.tmpl | \
  sed -e 's,%IMAGE%,'$IMAGE_NAME':'$IMAGE_TAG','g | \
  kubectl apply -f - -n $NAMESPACE

popd > /dev/null


